pitcharraytools.PitchArrayRow
=============================

.. abjad-lineage:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow

.. autoclass:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.cell_tokens
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.cell_widths
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.cells
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.depth
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.dimensions
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.is_defective
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.is_in_range
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.parent_array
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.pitches
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.row_index
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.storage_format
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.weight
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.width
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.pitch_range
   :noindex:

Methods
-------

.. automethod:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.append
   :noindex:

.. automethod:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.apply_pitches
   :noindex:

.. automethod:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.copy_subrow
   :noindex:

.. automethod:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.empty_pitches
   :noindex:

.. automethod:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.extend
   :noindex:

.. automethod:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.has_spanning_cell_over_index
   :noindex:

.. automethod:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.index
   :noindex:

.. automethod:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.merge
   :noindex:

.. automethod:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.pad_to_width
   :noindex:

.. automethod:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.pop
   :noindex:

.. automethod:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.remove
   :noindex:

.. automethod:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.withdraw
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.__add__
   :noindex:

.. automethod:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.__eq__
   :noindex:

.. automethod:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.__ge__
   :noindex:

.. automethod:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.__getitem__
   :noindex:

.. automethod:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.__gt__
   :noindex:

.. automethod:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.__iadd__
   :noindex:

.. automethod:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.__le__
   :noindex:

.. automethod:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.__len__
   :noindex:

.. automethod:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.__lt__
   :noindex:

.. automethod:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.__ne__
   :noindex:

.. automethod:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.__repr__
   :noindex:

.. automethod:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.__str__
   :noindex:
